@@ -34,6 +34,7 @@
 // The following define statement should occur before any include statements
 #define FORCE_PR_LOG       /* Allow logging even in release build */
 
+#include "ipc.h"
 #include "prlog.h"
 #include "nsAutoLock.h"
 #include "nsCRT.h"
@@ -119,8 +120,8 @@ nsPipeTransport::nsPipeTransport()
   nsresult rv;
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsPipeTransport:: <<<<<<<<< CTOR(%x): myThread=%x\n",
-         (int) this, (int) myThread.get()));
+  DEBUG_LOG(("nsPipeTransport:: <<<<<<<<< CTOR(%p): myThread=%p\n",
+         this, myThread.get()));
 #endif
 
 }
@@ -133,8 +134,8 @@ nsPipeTransport::~nsPipeTransport()
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsPipeTransport:: >>>>>>>>> DTOR(%x): myThread=%x START\n",
-         (int) this, (int) myThread.get()));
+  DEBUG_LOG(("nsPipeTransport:: >>>>>>>>> DTOR(%p): myThread=%p START\n",
+         this, myThread.get()));
 #endif
 
   Finalize(PR_TRUE);
@@ -143,7 +144,7 @@ nsPipeTransport::~nsPipeTransport()
   mInputStream  = nsnull;
   mOutputStream = nsnull;
 
-  DEBUG_LOG(("nsPipeTransport:: ********* DTOR(%x) END\n", (int) this));
+  DEBUG_LOG(("nsPipeTransport:: ********* DTOR(%p) END\n", this));
 }
 
 //
@@ -408,7 +409,7 @@ NS_IMETHODIMP nsPipeTransport::Init(const char *executable,
     rv = console->GetFileDesc(&stderrPipe);
     if (NS_FAILED(rv)) return rv;
 
-    DEBUG_LOG(("nsPipeTransport::Init: stderrPipe=0x%x\n", (int)stderrPipe));
+    DEBUG_LOG(("nsPipeTransport::Init: stderrPipe=0x%p\n", stderrPipe));
   }
 
   char** argList = NULL;
@@ -463,8 +464,13 @@ NS_IMETHODIMP nsPipeTransport::Init(const char *executable,
     return NS_ERROR_FILE_EXECUTION_FAILED;
   }
 
+#ifdef XP_WIN
   DEBUG_LOG(("nsPipeTransport::Init: Created process %d, %s\n",
-         (int) mProcess, mExecutable.get() ));
+	     (int) mProcess, mExecutable.get() ));
+#else
+  DEBUG_LOG(("nsPipeTransport::Init: Created process %d, %s\n",
+	     (int)(intptr_t) mProcess, mExecutable.get() ));
+#endif
 
   // Close process-side STDIN/STDOUT/STDERR pipes
   IPC_Close(stdinRead);
@@ -1083,7 +1089,7 @@ nsPipeTransport::ExecPrompt(const char* command, const char* prompt,
 {
   nsresult rv;
 
-  DEBUG_LOG(("nsPipeTransport::ExecPrompt: command='%s', prompt='%s', maxOutputLen=%d, clearPrev=%x\n", command, prompt, maxOutputLen, clearPrev));
+  DEBUG_LOG(("nsPipeTransport::ExecPrompt: command='%s', prompt='%s', maxOutputLen=%d, clearPrev=%p\n", command, prompt, maxOutputLen, clearPrev));
 
   if (!_retval)
     return NS_ERROR_NULL_POINTER;
@@ -1254,6 +1260,15 @@ nsPipeTransport::ReadLine(PRInt32 maxOutputLen,
       while (remainingCount > 0) {
         readMax = (remainingCount < kCharMax) ? remainingCount : kCharMax;
   
+        if (mStdoutPoller) {
+          // Fail if poller has been interrupted
+          PRBool interrupted;
+          rv = mStdoutPoller->IsInterrupted(&interrupted);
+          if (NS_FAILED(rv)) return rv;
+      
+          if (interrupted)
+            return NS_BASE_STREAM_CLOSED;
+        }
         rv = mInputStream->Read((char *) buf, kCharMax, &readCount);
         if (NS_FAILED(rv)) return rv;
   
@@ -1349,8 +1364,8 @@ nsPipeTransport::Cancel(nsresult status)
   nsresult rv;
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsPipeTransport::Cancel, myThread=%x, status=%x\n",
-         (int) myThread.get(), status));
+  DEBUG_LOG(("nsPipeTransport::Cancel, myThread=%p, status=%p\n",
+         myThread.get(), status));
 #endif
 
   // Need a non-zero status code to cancel
@@ -1462,8 +1477,8 @@ nsPipeTransport::Write(const char *buf, PRUint32 count, PRUint32 *_retval)
 
   if (writeCount != (PRInt32) count) {
     PRErrorCode errCode = IPC_GetError();
-    DEBUG_LOG(("nsPipeTransport::Write: Error in writing to fd %x (count=%d, writeCount=%d, error code=%d)\n",
-               (int) mStdinWrite, count, writeCount, (int) errCode));
+    DEBUG_LOG(("nsPipeTransport::Write: Error in writing to fd %p (count=%d, writeCount=%d, error code=%d)\n",
+               mStdinWrite, count, writeCount, errCode));
   }
 
   if (writeCount < 0)
@@ -1550,7 +1565,7 @@ nsPipeTransport::OnDataAvailable(nsIRequest* aRequest, nsISupports* aContext,
     readMax = (aLength < kCharMax) ? aLength : kCharMax;
     rv = aInputStream->Read((char *) buf, readMax, &readCount);
     if (NS_FAILED(rv)){
-      DEBUG_LOG(("nsPipeTransport::OnDataAvailable: Error in reading from input stream, %x\n", rv));
+      DEBUG_LOG(("nsPipeTransport::OnDataAvailable: Error in reading from input stream, %p\n", rv));
       return rv;
     }
 
@@ -1581,7 +1596,7 @@ nsPipeTransport::OnInputStreamReady(nsIAsyncInputStream* inStr)
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsPipeTransport::OnInputStreamReady, myThread=%x\n", (int)myThread.get()));
+  DEBUG_LOG(("nsPipeTransport::OnInputStreamReady, myThread=%p\n", myThread.get()));
 #endif
 
   if (mListener) {
@@ -1629,7 +1644,7 @@ nsPipeTransport::OnOutputStreamReady(nsIAsyncOutputStream* outStr)
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsPipeTransport::OnOutputStreamReady, myThread=%x\n", (int)myThread.get()));
+  DEBUG_LOG(("nsPipeTransport::OnOutputStreamReady, myThread=%p\n", myThread.get()));
 #endif
 
   return NS_OK;
@@ -1650,7 +1665,7 @@ nsPipeTransport::OnEmpty(nsIInputStream* inStr)
   nsresult rv;
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsPipeTransport::OnEmpty, myThread=%x\n", (int)myThread.get()));
+  DEBUG_LOG(("nsPipeTransport::OnEmpty, myThread=%p\n", myThread.get()));
 #endif
 
   return NS_OK;
@@ -1663,7 +1678,7 @@ nsPipeTransport::OnClose(nsIInputStream* inStr)
   nsresult rv;
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsPipeTransport::OnClose, myThread=%x\n", (int)myThread.get()));
+  DEBUG_LOG(("nsPipeTransport::OnClose, myThread=%p\n", myThread.get()));
 #endif
 
   return NS_OK;
@@ -1682,7 +1697,7 @@ nsPipeTransport::OnWrite(nsIOutputStream* outStr, PRUint32 aCount)
   nsresult rv;
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsPipeTransport::OnWrite, myThread=%x\n", (int)myThread.get()));
+  DEBUG_LOG(("nsPipeTransport::OnWrite, myThread=%p\n", myThread.get()));
   DEBUG_LOG(("nsPipeTransport::OnWrite, count=%d\n", aCount));
 #endif
 
@@ -1703,7 +1718,7 @@ nsPipeTransport::OnFull(nsIOutputStream* outStr)
   nsresult rv;
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsPipeTransport::OnFull, myThread=%x\n", (int)myThread.get()));
+  DEBUG_LOG(("nsPipeTransport::OnFull, myThread=%p\n", myThread.get()));
 #endif
   return NS_OK;
 }
@@ -1723,7 +1738,7 @@ nsPipeTransport::ParseMimeHeaders(const char* mimeHeaders, PRUint32 count,
   nsresult rv;
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsPipeTransport::ParseMimeHeaders, myThread=%x\n", (int)myThread.get()));
+  DEBUG_LOG(("nsPipeTransport::ParseMimeHeaders, myThread=%p\n", myThread.get()));
 #endif
 
   if (mHeaderProcessor)
@@ -1745,7 +1760,7 @@ nsPipeTransport::StartRequest()
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsPipeTransport::StartRequest, myThread=%x\n",(int)myThread.get()));
+  DEBUG_LOG(("nsPipeTransport::StartRequest, myThread=%p\n",myThread.get()));
 #endif
 
   if (mListener) {
@@ -1770,8 +1785,8 @@ nsPipeTransport::StopRequest(nsresult aStatus)
   nsresult rv;
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsPipeTransport::StopRequest, myThread=%x, status=%x\n",
-         (int) myThread.get(), aStatus));
+  DEBUG_LOG(("nsPipeTransport::StopRequest, myThread=%p, status=%p\n",
+         myThread.get(), aStatus));
 #endif
 
   // NOTE: Should OnStopRequest be called if request is being cancelled?
@@ -1832,8 +1847,8 @@ nsStdoutPoller::nsStdoutPoller()
   nsresult rv;
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsStdoutPoller:: <<<<<<<<< CTOR(%x): myThread=%x\n",
-         (int) this, (int) myThread.get()));
+  DEBUG_LOG(("nsStdoutPoller:: <<<<<<<<< CTOR(%p): myThread=%p\n",
+         this, myThread.get()));
 #endif
 
   mLock = PR_NewLock();
@@ -1846,8 +1861,8 @@ nsStdoutPoller::~nsStdoutPoller()
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsStdoutPoller:: >>>>>>>>> DTOR(%x): myThread=%x\n",
-         (int) this, (int) myThread.get()));
+  DEBUG_LOG(("nsStdoutPoller:: >>>>>>>>> DTOR(%p): myThread=%p\n",
+         this, myThread.get()));
 #endif
 
   Finalize(PR_TRUE);
@@ -2039,8 +2054,8 @@ nsStdoutPoller::IsInterrupted(PRBool* interrupted)
   nsresult rv;
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsStdoutPoller::IsInterrupted: %x, myThread=%x\n", 
-         mInterrupted, (int) myThread.get()));
+  DEBUG_LOG(("nsStdoutPoller::IsInterrupted: %p, myThread=%p\n", 
+         mInterrupted, myThread.get()));
 #endif
 
   if (!interrupted)
@@ -2094,7 +2109,7 @@ nsStdoutPoller::Interrupt(PRBool* alreadyInterrupted)
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsStdoutPoller::Interrupt: myThread=%x\n", (int)myThread.get()));
+  DEBUG_LOG(("nsStdoutPoller::Interrupt: myThread=%p\n", myThread.get()));
 #endif
 
   if (mPollableEvent) {
@@ -2130,8 +2145,8 @@ nsStdoutPoller::GetPolledFD(PRFileDesc*& aFileDesc)
     return NS_OK;
   }
 
-  DEBUG_LOG(("nsStdoutPoller::GetPolledFD: ***PR_Poll 0x%x,%d,%d\n",
-             (int)mPollFD, mPollCount, mTimeoutInterval));
+  DEBUG_LOG(("nsStdoutPoller::GetPolledFD: ***PR_Poll 0x%p,%d,%d\n",
+             mPollFD, mPollCount, mTimeoutInterval));
 
   pollRetVal = PR_Poll(mPollFD, mPollCount, mTimeoutInterval);
 
@@ -2146,7 +2161,7 @@ nsStdoutPoller::GetPolledFD(PRFileDesc*& aFileDesc)
 #ifdef FORCE_PR_LOG
       nsCOMPtr<nsIThread> myThread;
       rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-      DEBUG_LOG(("nsStdoutPoller::GetPolledFD: Interrupted (NSPR) while polling, myThread=0x%x\n", (int) myThread.get()));
+      DEBUG_LOG(("nsStdoutPoller::GetPolledFD: Interrupted (NSPR) while polling, myThread=0x%p\n", myThread.get()));
 #endif
     }
 
@@ -2165,7 +2180,7 @@ nsStdoutPoller::GetPolledFD(PRFileDesc*& aFileDesc)
   PRBool errFlags = PR_FALSE;
   for (int j=0; j<mPollCount; j++) {
 
-    DEBUG_LOG(("nsStdoutPoller::GetPolledFD: mPollFD[%d].out_flags=0x%x\n",
+    DEBUG_LOG(("nsStdoutPoller::GetPolledFD: mPollFD[%d].out_flags=0x%p\n",
             j, mPollFD[j].out_flags));
 
     if (mPollFD[j].out_flags) {
@@ -2191,7 +2206,7 @@ nsStdoutPoller::GetPolledFD(PRFileDesc*& aFileDesc)
         nsCOMPtr<nsIThread> myThread;
         rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
         WARNING_LOG(("nsStdoutPoller::GetPolledFD: mPollFD[%d]: Exception/error 0x%x, myThread=0x%x\n",
-         j, mPollFD[j].out_flags, (int) myThread.get()));
+         j, mPollFD[j].out_flags, myThread.get()));
 #endif
         errFlags = PR_TRUE;
       }
@@ -2343,7 +2358,7 @@ nsStdoutPoller::Run()
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsStdoutPoller::Run: myThread=%x\n", (int) myThread.get()));
+  DEBUG_LOG(("nsStdoutPoller::Run: myThread=%p\n", myThread.get()));
 #endif
 
   if (!mPollCount) 
@@ -2387,8 +2402,8 @@ nsStdoutPoller::Run()
         break;
       } else {
         // Exit loop with error status
-        WARNING_LOG(("nsStdoutPoller::Run: Error in reading from fd %x (readCount=%d, error code=%d)\n",
-                     (int) readHandle, readCount, (int) errCode ));
+        WARNING_LOG(("nsStdoutPoller::Run: Error in reading from fd %p (readCount=%d, error code=%d)\n",
+                     readHandle, readCount, (int) errCode ));
 
         rv = NS_ERROR_FAILURE;
         break;
@@ -2471,7 +2486,7 @@ nsStdoutPoller::Run()
   // Kill process, and release owning references
   Finalize(PR_FALSE);
 
-  DEBUG_LOG(("nsStdoutPoller::Run: exiting, rv=%x\n", rv));
+  DEBUG_LOG(("nsStdoutPoller::Run: exiting, rv=%p\n", rv));
 
   return rv;
 }
@@ -2499,8 +2514,8 @@ nsStdinWriter::nsStdinWriter()
   nsresult rv;
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsStdinWriter:: <<<<<<<<< CTOR(%x): myThread=%x\n",
-         (int) this, (int) myThread.get()));
+  DEBUG_LOG(("nsStdinWriter:: <<<<<<<<< CTOR(%p): myThread=%p\n",
+         this, myThread.get()));
 #endif
 }
 
@@ -2511,8 +2526,8 @@ nsStdinWriter::~nsStdinWriter()
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsStdinWriter:: >>>>>>>>> DTOR(%x): myThread=%x\n",
-         (int) this, (int) myThread.get()));
+  DEBUG_LOG(("nsStdinWriter:: >>>>>>>>> DTOR(%p): myThread=%p\n",
+         this, myThread.get()));
 #endif
 
   if (mPipe != IPC_NULL_HANDLE) {
@@ -2561,7 +2576,7 @@ nsStdinWriter::Run()
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsStdinWriter::Run: myThread=%x\n", (int) myThread.get()));
+  DEBUG_LOG(("nsStdinWriter::Run: myThread=%p\n", myThread.get()));
 #endif
 
   char buf[kCharMax];
@@ -2587,8 +2602,8 @@ nsStdinWriter::Run()
 
     if (writeCount != (int) readCount) {
       PRErrorCode errCode = IPC_GetError();
-      DEBUG_LOG(("nsStdinWriter::Run: Error in writing to fd %x (count=%d, writeCount=%d, error code=%d)\n",
-                 (int) mPipe, readCount, writeCount, (int) errCode));
+      DEBUG_LOG(("nsStdinWriter::Run: Error in writing to fd %p (count=%d, writeCount=%d, error code=%d)\n",
+                 mPipe, readCount, writeCount, (int) errCode));
 
       rv = NS_ERROR_FAILURE;
       break;
@@ -2607,7 +2622,7 @@ nsStdinWriter::Run()
     mInputStream->Close();
   }
 
-  DEBUG_LOG(("nsStdinWriter::Run: exiting, rv=%x\n", rv));
+  DEBUG_LOG(("nsStdinWriter::Run: exiting, rv=%p\n", rv));
 
   return rv;
 }
